function [errorCount, classEst, neighborClassLabels] = evaluateTestsKnn( ...
  neighborhoodSize, simMat, testIdx, classLabels, simType)
%evaluateTestsKnn
% REDO HELP
% Compute the local SDA classification results for test splits. 
% This functions is designed to be used in conjunction with
% readPartitionFile() and with the partition files from the Similarity
% Learning Repository.
%
% USAGE
% [errorCount, classEst, neighorClassLabels] = evaluateTestsLocalSda( ...
%     neighborhoodSize, simMat, testIdx, classLabels, simType)
% neighbrohoodSize: neighborhood size to use.
% simMat: N-by-N matrix of pairwise similarities.
% testIdx: vector of indices into simMat denoting the samples to be tested.
%    It is a row from testIdxMat as returned by readPartitionFile().
% classLabels: N-by-1 vector of class labels for each column of simMat.
% simDomain: vector of possible similarity values.
% errorCount: number of misclassified test samples.
% classEst: M-by-1 vector of class estimates returned by the local SDA
%     classifier, where M is the number of test samples (the length of
%     testIdx).
% posteriors: M-by-1 cell array, each element containing the class
%     posterior proabilities computed by the local SDA classifier.
% modelParams: M-by-1 cell array, each element containing the local SDA
%     model parameters for a test sample. 
%
% See also crossValidateNeighborhoodLocalSda, readPartitionFile.

% Written by Luca Cazzanti, engineer.
% Applied Physics Laboratory, University of Washington, Feb 2007.
%$Id:$
%$DateTime:$
%$Author:$

neighborIdx = findNearNeighbors(simMat, size(simMat,2), simType);
neighborIdx = adjustSelfSimilarityRank(neighborIdx);
neighborIdx(:,1) = [];

nTests = length(testIdx);    
classEst = -1e6 * ones(nTests,1);
trueClass = classLabels(testIdx);
neighborClassLabels = -1e6 * ones(nTests, neighborhoodSize);

uniqueClassLabels = unique(classLabels);
nClasses = length(uniqueClassLabels);

% Iterate through all the test samples 
for iTest = 1:nTests

  thisTestSampleIdx = testIdx(iTest);

  % Pull out the test sample's neighbors
  neighborsToThisTestSample = neighborIdx(thisTestSampleIdx,:);

  % Remove the other test samples from this sample's possible
  % neighbors: this keeps the tests completely disjoint
  for jTest = 1:nTests
    idx = find( neighborsToThisTestSample == testIdx(jTest) );
    neighborsToThisTestSample(idx) = [];
  end % for jTest

  neighborsToPick = neighborsToThisTestSample(1:neighborhoodSize);
  neighborClassLabels(iTest,:) = classLabels(neighborsToPick);
  
  % Here's the classification rule
  classEst(iTest) = classifyKnn(neighborClassLabels(iTest,:), ...
    uniqueClassLabels);
  
end %for iTest

errorCount = sum( classEst(:) ~= trueClass(:) );

return