function modelParams = alignLocalModel(localModelParams, ...
  possibleClassLabels)
%alignLocalModel - 
% TO DO: HELP

% Written by Luca Cazzanti, engineer.
% Applied Physics Laboratory, University of Washington, Jan 2009.

nPossibleClasses = length(possibleClassLabels);
localClassLabels = localModelParams.classLabels;
nLocalClasses = length(localClassLabels);


classCounts = zeros(nPossibleClasses);
lambdaMat = -Inf * ones(nPossibleClasses, nPossibleClasses);
gammaMat = ones(nPossibleClasses, nPossibleClasses);
meanSimMat = -Inf * ones(nPossibleClasses, nPossibleClasses);
for gClass = 1:nLocalClasses
  rowIdx = find(possibleClassLabels == localClassLabels(gClass));
  classCounts(rowIdx) = localModelParams.classCounts(gClass);
  for hClass = 1:nLocalClasses
    colIdx = find(possibleClassLabels == localClassLabels(hClass));
    lambdaMat(rowIdx, colIdx) = localModelParams.lambda(gClass, hClass);
    gammaMat(rowIdx, colIdx) = localModelParams.gamma(gClass, hClass);
    meanSimMat(rowIdx, colIdx) = localModelParams.meanSim(gClass, hClass);
  end % for hClass
end %for gClass

% note Laplace correction for priors
classPriors = (classCounts + 1 )/( sum(classCounts) + nPossibleClasses); 

% Put the aligned models back into the model structure
modelParams = localModelParams;
modelParams.gamma = gammaMat;
modelParams.lambda = lambdaMat;
modelParams.meanSim = meanSimMat;
modelParams.classCounts = classCounts;
modelParams.classPriors = classPriors;
modelParams.classLabels = possibleClassLabels;

