function [classEst, modelParams] = classifyLocalNearestCentroid( ...
  testPointSim, neighborSimMat, neighborClassLabels, centroidType)
%classifyLocalNearestCentroid - locally classify based on nearest centroid.
% Classifies a test point based on its similarity to the centroids of a set
% of other points, for example its K most similar points. The class of the
% nearest (most similar) centroid determines the class of the test point.
%
% USAGE
% [classEst, modelParams] = classifyLocalNearestCentroid(simVec, simMat, ...
%     classLabels, centroidType)
% simVec: vector of test point similarities to each of the set points.
% simMat:  matrix of pairwise similarities of all set points.
% classLabels: class labels of the points in the set.
% centroidType: string denoting the type of centroid to use. See
%     findCentroid() for a list of allowed centroid types.
% classEst:  class estimate for the test point.
% modelParams: the nearest centroid model parameters computed by
% computeCentroidModels() from simMat.
%
% This function consists of a call to computeCentroidModels() and a call
% to classifyNearestCentroid(). See those functions for more details on the
% structure of modelParams.

% Written by Luca Cazzanti, engineer.
% Applied Physics Laboratory, University of washington, December 2006.
%$Id:$
%$DateTime:$
%$Author:$

modelParams = computeCentroidModels(neighborSimMat, ...
  neighborClassLabels, centroidType);
classEst = classifyNearestCentroid(testPointSim, modelParams);

return
 