function regularizingParams = createRegularizedMeanParamStruct( ...
  meanType, regMean, regParam, neighborType, centroidType, ...
  nNeighbors, simDomain, classLabels)
%createRegularizingMeanParamStruct - create structure for mean-regularized local SDA.
% Creates a structure whose fields are necessary parameters for the
% mean-regularized local SDA classifier. 
% USAGE
% paramStruct = createRegularizedMeanParamStruct( ...
%    meanType, regMean, regParam, neighborType, centroidType, ...
%    nNeighbors, simDomain, classLabels)
% meanType - either 'average' or 'global'
% regMean - a C-by-C matrix of mean similarities that regularize the
%     local SDA mean similarities, where C is the number of classes.
% regParam - the regularization constant
% neighborType - either 'kPerClass' or 'kTotal'
% centroidType - only 'maxSumSim' has been tested
% nNeighbors - number of neighbors for local SDA
% simDomain - vector of possible similarity values
% classLabels - vector of numeric labels for the C classes
% paramStruct - the parameters structure, with fieldnames identical to the
%     input parameter names.
%
% See also classifyRegularizedMeanLocalSda.

% Written by Luca Cazzanti, engineer.
% Applied Physics Laboratory, University of Washington, March 2009.
%$Id:$
%$DateTime:$
%$Author:$

regularizingParams.meanType = meanType;
regularizingParams.regMean = regMean;
regularizingParams.regParam = regParam;
regularizingParams.neighborType = neighborType;
regularizingParams.centroidType = centroidType;
regularizingParams.nNeighbors = nNeighbors;
regularizingParams.simDomain = simDomain;
regularizingParams.classLabels = classLabels;

return
